@@ -3,8 +3,7 @@ package URI;
 use strict;
 use warnings;
 
-our $VERSION = '1.70_001';
-$VERSION = eval $VERSION;
+our $VERSION = "1.66";
 
 our ($ABS_REMOTE_LEADING_DOTS, $ABS_ALLOW_RELATIVE_SCHEME, $DEFAULT_QUERY_FORM_DELIMITER);
 
@@ -95,7 +94,6 @@ sub _uric_escape
     return $str;
 }
 
-my %require_attempted;
 
 sub implementor
 {
@@ -130,13 +128,9 @@ sub implementor
     no strict 'refs';
     # check we actually have one for the scheme:
     unless (@{"${ic}::ISA"}) {
-        if (not exists $require_attempted{$ic}) {
-            # Try to load it
-            my $_old_error = $@;
-            eval "require $ic";
-            die $@ if $@ && $@ !~ /Can\'t locate.*in \@INC/;
-            $@ = $_old_error;
-        }
+        # Try to load it
+        eval "require $ic";
+        die $@ if $@ && $@ !~ /Can\'t locate.*in \@INC/;
         return undef unless @{"${ic}::ISA"};
     }
 
@@ -996,12 +990,6 @@ C<URI> objects belonging to the ssh scheme support the common,
 generic and server methods. In addition, they provide methods to
 access the userinfo sub-components: $uri->user and $uri->password.
 
-=item B<sftp>:
-
-C<URI> objects belonging to the sftp scheme support the common,
-generic and server methods. In addition, they provide methods to
-access the userinfo sub-components: $uri->user and $uri->password.
-
 =item B<urn>:
 
 The syntax of Uniform Resource Names is specified in RFC 2141.  C<URI>
